<template>
  <div>
    <el-input placeholder="请选择" :value="name" disabled>
      <el-button slot="append" icon="el-icon-thumb" @click="handleClick"></el-button>
    </el-input>
    <el-dialog title="服务器" :visible.sync="open" width="1000px" :append-to-body="true" :destroy-on-close="true">
      <server-list v-if="open" ref="serverRef" :schoolId="schoolId"></server-list>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="open = false">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import serverList from "./list";
import {getServer} from "@/api/oa/server";

/**
 * 高校NVR
 */
export default {
  name: "ServerInput",
  components: {
    serverList
  },
  model: {
    prop: 'value',
    event: 'change'
  },
  props: {
    value: {
      type: [Number],
      default: undefined
    },
    schoolId: {
      type: Number,
      default: undefined
    }
  },
  data() {
    return {
      open: false,
      name: ''
    }
  },
  watch: {
    'value': function (v) {
      if (v) {
        getServer(v).then(response => {
          this.name = response.data.deploymentName;
        });
      }else {
        this.name = '';
      }
    }
  },
  created() {
    if (this.value) {
      getServer(this.value).then(response => {
        this.name = response.data.deploymentName;
      });
    }
  },
  methods: {
    handleClick() {
      this.open = true;
    },
    submitForm() {
      const row = this.$refs.serverRef.currentRow;
      if (!row) {
        this.$message.warning("请选择一条数据")
        this.buttonLoading = false;
        return;
      }
      this.name = row.deploymentName;
      this.open = false;
      this.$emit("change", row.id);
    }
  }
}
</script>

<style scoped>

</style>